## 每日筹码及胜率

接口：cyq_perf

描述：获取A股每日筹码平均成本和胜率情况，每天17~18点左右更新，数据从2018年开始

来源：Tushare社区

限量：单次最大5000条，可以分页或者循环提取

积分：120积分可以试用(查看数据)，5000积分每天20000次，10000积分每天200000次，15000积分每天不限总量

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码 |
| trade_date | str | N | 交易日期（YYYYMMDD） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| trade_date | str | Y | 交易日期 |
| his_low | float | Y | 历史最低价 |
| his_high | float | Y | 历史最高价 |
| cost_5pct | float | Y | 5分位成本 |
| cost_15pct | float | Y | 15分位成本 |
| cost_50pct | float | Y | 50分位成本 |
| cost_85pct | float | Y | 85分位成本 |
| cost_95pct | float | Y | 95分位成本 |
| weight_avg | float | Y | 加权平均成本 |
| winner_rate | float | Y | 胜率 |

接口用法

```python
pro = ts.pro_api()

df = pro.cyq_perf(ts_code='600000.SH', start_date='20220101', end_date='20220429')
```

数据样例

```python
ts_code trade_date his_low his_high cost_5pct cost_95pct weight_avg winner_rate
0   600000.SH   20220429    0.72    12.16      8.18      11.34       9.76        3.52
```